# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.3](https://github.com/denehoffman/gluex-rs/compare/gluex-ccdb-py-v0.1.2...gluex-ccdb-py-v0.1.3) (2026-01-22)

## [Unreleased]

## [0.1.2](https://github.com/denehoffman/gluex-rs/compare/gluex-ccdb-py-v0.1.1...gluex-ccdb-py-v0.1.2) - 2026-01-21

### Other

- update Cargo.toml dependencies

## [0.1.1](https://github.com/denehoffman/gluex-rs/compare/gluex-ccdb-py-v0.1.0...gluex-ccdb-py-v0.1.1) - 2025-12-18

### Added

- add fetch method which incorporates REST version timestamps and run period selection
